@@ -157,7 +157,7 @@ struct FastqParams final : CmnOptAndAccessions
             "number of reads, this option will produce files that WILL CAUSE ERRORS in most programs "
             "which process split pair fastq files." );
 
-        cmdline . addOption ( split3, "", "split-e",
+        cmdline . addOption ( split3, "", "split-3",
             "3-way splitting for mate-pairs. For each spot, if there are two biological reads "
             "satisfying filter conditions, the first is placed in the `*_1.fastq` file, and the "
             "second is placed in the `*_2.fastq` file. If there is only one biological read "
@@ -201,6 +201,11 @@ struct FastqParams final : CmnOptAndAccessions
             "string or for numeric variables. Ex: @$sn[_$rn]/$ri '_$rn' is omitted if name is empty" );
 
         CmnOptAndAccessions::add(cmdline);
+
+        // add a silent option...
+        cmdline . startSilentOptions();
+        cmdline . addOption ( split3, "", "split-e", "See split-3" );
+
     }
 
     std::ostream &show(std::ostream &ss) const override
@@ -245,7 +250,7 @@ struct FastqParams final : CmnOptAndAccessions
 
     void populate_argv_builder( ArgvBuilder & builder, int acc_index, std::vector<ncbi::String> const &accessions ) const override
     {
-        CmnOptAndAccessions::populate_argv_builder(builder, acc_index, accessions);
+        populate_common_argv_builder(builder, acc_index, accessions, fastq_dump);
 
         if ( !accession_replacement.isEmpty() ) builder . add_option( "-A", accession_replacement );
         if ( !table_name.isEmpty() ) builder . add_option( "--table", table_name );
@@ -324,6 +329,16 @@ struct FastqParams final : CmnOptAndAccessions
     bool check() const override
     {
         int problems = 0;
+
+        if (!fasta.isEmpty() && fasta != "default") {
+            for (auto && ch : fasta.toSTLString()) {
+                if (ch < '0' || ch > '9') {
+                    std::cerr << "fasta requires an integer value >= 0 or \"default\"" << std::endl;
+                    problems++;
+                    break;
+                }
+            }
+        }
         if ( bzip && gzip )
         {
             std::cerr << "bzip2 and gzip cannot both be used at the same time" << std::endl;
