@@ -36,6 +36,8 @@
 
 #include <kdb/manager.h>
 #include <vdb/manager.h>
+#include <vfs/manager.h>
+#include <vfs/path.h>
 
 rc_t ErrMsg( const char * fmt, ... )
 {
@@ -792,6 +794,23 @@ bool ends_in_slash( const char * s )
     return res;
 }
 
+static bool ends_in_sra( const char * s )
+{
+    bool res = false;
+    if ( s != NULL )
+    {
+        uint32_t len = string_measure( s, NULL );
+        if ( len > 4 )
+        {
+            res = ( ( s[ len - 1 ] == 'a' ) &&
+                    ( s[ len - 2 ] == 'r' ) &&
+                    ( s[ len - 3 ] == 's' ) &&
+                    ( s[ len - 4 ] == '.' ) );
+        }
+    }
+    return res;
+}
+
 bool extract_path( const char * s, String * path )
 {
     bool res = false;
@@ -816,20 +835,68 @@ bool extract_path( const char * s, String * path )
     return res;
 }
 
+
 const char * extract_acc( const char * s )
 {
     const char * res = NULL;
-    if ( s != NULL )
+    if ( ( s != NULL ) && ( ! ends_in_slash( s ) ) )
     {
-        if ( !ends_in_slash( s ) )
+        size_t size = string_size ( s );
+        char * slash = string_rchr ( s, size, '/' );
+        if ( slash == NULL )
         {
-            size_t size = string_size ( s );
-            char * slash = string_rchr ( s, size, '/' );
-            if ( slash == NULL )
-                res = s;
+            if ( ends_in_sra( s ) )
+            {
+                res = string_dup ( s, size - 4 );
+            }
             else
-                res = slash + 1;
+            {
+                res = string_dup ( s, size );
+            }
         }
+        else
+        {
+            char * tmp = slash + 1;
+            if ( ends_in_sra( tmp ) )
+            {
+                res = string_dup ( tmp, string_size ( tmp ) - 4 );
+            }
+            else
+            {
+                res = string_dup ( tmp, string_size ( tmp ) );
+            }
+        }
+    }
+    return res;
+}
+
+const char * extract_acc2( const char * s )
+{
+    const char * res = NULL;
+    VFSManager * mgr;
+    rc_t rc = VFSManagerMake ( &mgr );
+    if ( 0 == rc )
+    {
+        VPath * orig;
+        rc = VFSManagerMakePath ( mgr, &orig, "%s", s );
+        if ( 0 == rc )
+        {
+            VPath * acc_or_oid;
+            rc = VFSManagerExtractAccessionOrOID( mgr, &acc_or_oid, orig );
+            if ( 0 == rc )
+            {
+                char buffer[ 1024 ];
+                size_t num_read;
+                rc = VPathReadPath ( acc_or_oid, buffer, sizeof buffer, &num_read );
+                if ( 0 == rc )
+                {
+                    res = string_dup ( buffer, num_read );
+                }
+                VPathRelease ( acc_or_oid );
+            }
+            VPathRelease ( orig );
+        }
+        VFSManagerRelease ( mgr );
     }
     return res;
 }
@@ -1262,3 +1329,12 @@ bool match_Buf2NA( Buf2NA * self, const String * ascii )
     }
     return res;
 }
+
+rc_t helper_make_thread( KThread ** self,
+                         rc_t ( CC * run_thread ) ( const KThread * self, void * data ),
+                         void * data,
+                         size_t stacksize )
+{
+    rc_t rc = KThreadMakeStackSize( self, run_thread, data, stacksize );
+    return rc;
+}
