@@ -137,7 +137,7 @@ static rc_t MaxNReadsValidator_Release( const SRASplitter* cself )
     else if ( !g_legacy_report )
     {
         if ( self->rejected_spots > 0 )
-            rc = KOutMsg( "Rejected %lu SPOTS because of to many READS\n", self->rejected_spots );
+            rc = KOutMsg( "Rejected %lu SPOTS because of too many READS\n", self->rejected_spots );
     }
     return rc;
 }
@@ -664,8 +664,9 @@ static const SRADumperFmt_Arg KMainArgs[] =
     { "A",   "accession",        "accession",   { "Replaces accession derived from <path> in filename(s) and deflines (only for single table dump)", NULL } },
     { "O",   "outdir",           "path",        { "Output directory, default is working directory ( '.' )", NULL } },
     { "Z",   "stdout",           NULL,          { "Output to stdout, all split data become joined into single stream", NULL } },
-    { NULL, "gzip",              NULL,         { "Compress output using gzip", NULL } },
-    { NULL, "bzip2",             NULL,         { "Compress output using bzip2", NULL } },
+    { NULL,  "ngc",              "path",       { "<path> to ngc file", NULL } },
+    { NULL, "gzip",              NULL,         { "Compress output using gzip: deprecated, not recommended", NULL } },
+    { NULL, "bzip2",             NULL,         { "Compress output using bzip2: deprecated, not recommended", NULL } },
     { "N",   "minSpotId",        "rowid",       { "Minimum spot id", NULL } },
     { "X",   "maxSpotId",        "rowid",       { "Maximum spot id", NULL } },
     { "G",   "spot-group",       NULL,          { "Split into files by SPOT_GROUP (member name)", NULL } },
@@ -851,7 +852,10 @@ bool CC SRADumper_GetArg( const SRADumperFmt* fmt, char const* const abbr, char
     }
     else if ( value != NULL )
     {
-        if ( arg == NULL && *value == '\0' )
+        /* this code is very old and very obtuse.
+           was the intention to try to access value[0][0]?
+           original expression had " *value == '\0' " */
+        if ( arg == NULL && *value == NULL )
         {
             rc = RC( rcApp, rcArgv, rcAccessing, rcParam, rcNotFound );
         }
@@ -1121,6 +1125,9 @@ rc_t CC KMain ( int argc, char* argv[] )
         {
             to_stdout = true;
         }
+        else if (SRADumper_GetArg(&fmt, NULL, "ngc", &i, argc, argv, &arg)) {
+            KConfigSetNgcFile(arg);
+        }
         else if ( fmt.gzip && SRADumper_GetArg( &fmt, NULL, "gzip", &i, argc, argv, NULL ) )
         {
             do_gzip = true;
