@@ -222,7 +222,7 @@ public:
             }
         }
         if (rc == 0) {
-            m_Config = new vdbconf_model(m_Cfg.Get());
+            m_Config = new vdbconf_model( m_Cfg );
             if (m_Config == NULL) {
                 rc = TODO;
             }
@@ -236,11 +236,6 @@ public:
         OUTMSG(("Fixed default configuration\n"));
         return 0;
     }
-
-    vdbconf_model *getModel ()
-    {
-        return m_Config;
-    }
 };
 struct SUserRepo {
     bool cacheEnabled;
@@ -377,7 +372,7 @@ class CTextualConfigurator : public CConfigurator {
             return "";
         }
     }
-    
+
     void ProcessCancel(SData &d) {
         if (!d.updated) {
             d.done = true;
@@ -793,16 +788,24 @@ class CTextualConfigurator : public CConfigurator {
 public:
     CTextualConfigurator(void) {}
 };
-const string CTextualConfigurator::CSymGen::magic
- ("56789ABCDEFGHIJKLMNOPQRSTUVWXZ");
-class CVisualConfigurator : public CConfigurator {
-    virtual rc_t Configure(void) {
-        if (m_Config == NULL) {
+const string CTextualConfigurator::CSymGen::magic("56789ABCDEFGHIJKLMNOPQRSTUVWXZ");
+
+class CVisualConfigurator : public CConfigurator
+{
+    virtual rc_t Configure( void )
+    {
+        if ( m_Config == NULL )
+        {
             return TODO;
         }
-        return run_interactive(*m_Config);
+        /* here we can switch between:
+             - the old view : run_interactive() just repositories and caching
+             - the new view : run_interactive2() with cloud settings and repositories
+         */
+        return run_interactive2( *m_Config );
     }
 };
+
 rc_t configure(EConfigMode mode) {
     rc_t rc = 0;
     CConfigurator *c = NULL;
@@ -834,11 +837,3 @@ rc_t configure(EConfigMode mode) {
     return rc;
 }
 
-vdbconf_model & configure_model ()
-{
-    CConfigurator *c = new CVisualConfigurator;
-    vdbconf_model *m = c -> getModel ();
-    //delete c;
-
-    return *m;
-}
