@@ -33,6 +33,9 @@
 #include <klib/text.h>
 #include <klib/num-gen.h>
 #include <kapp/args.h>
+
+#include <kfg/config.h> /* KConfigSetNgcFile */
+
 #include <os-native.h>
 #include <sysalloc.h>
 
@@ -139,7 +142,8 @@ static void vdco_init_values( p_dump_context ctx )
     ctx->show_spotgroups = false;
     ctx->show_spread = false;
     ctx->len_spread = false;
-    ctx->interactive = false;    
+    ctx->interactive = false; 
+    ctx->append = false;
 }
 
 rc_t vdco_init( dump_context **ctx )
@@ -595,7 +599,8 @@ static void vdco_evaluate_options( const Args *my_args,
     ctx->without_sra_types = vdco_get_bool_option( my_args, OPTION_WITHOUT_SRA, false );
     ctx->print_num_elem = vdco_get_bool_option( my_args, OPTION_NUMELEM, false );
     ctx->sum_num_elem = vdco_get_bool_option( my_args, OPTION_NUMELEMSUM, false );
-    ctx->show_blobbing = vdco_get_bool_option( my_args, OPTION_SHOW_BLOBBING, false );
+    ctx->show_kdb_blobs = vdco_get_bool_option( my_args, OPTION_SHOW_KDB_BLOBS, false );
+    ctx->show_vdb_blobs = vdco_get_bool_option( my_args, OPTION_SHOW_VDB_BLOBS, false );
     ctx->enum_phys = vdco_get_bool_option( my_args, OPTION_ENUM_PHYS, false );
     ctx->enum_readable = vdco_get_bool_option( my_args, OPTION_ENUM_READABLE, false );
     ctx->enum_static = vdco_get_bool_option( my_args, OPTION_ENUM_STATIC, false );
@@ -610,6 +615,7 @@ static void vdco_evaluate_options( const Args *my_args,
     ctx->len_spread = vdco_get_bool_option( my_args, OPTION_LEN_SPREAD, false );
     ctx->interactive = vdco_get_bool_option( my_args, OPTION_INTERACTIVE, false );
     ctx->slice_depth = vdco_get_uint16_option( my_args, OPTION_SLICE, 0 );
+    ctx->append = vdco_get_bool_option( my_args, OPTION_APPEND, false );
     
     ctx->cur_cache_size = vdco_get_size_t_option( my_args, OPTION_CUR_CACHE, CURSOR_CACHE_SIZE );
     ctx->output_buffer_size = vdco_get_size_t_option( my_args, OPTION_OUT_BUF_SIZE, DEF_OPTION_OUT_BUF_SIZE );
@@ -636,6 +642,12 @@ static void vdco_evaluate_options( const Args *my_args,
     vdco_set_filter( ctx, vdco_get_str_option( my_args, OPTION_FILTER ) );
     vdco_set_boolean_char( ctx, vdco_get_str_option( my_args, OPTION_BOOLEAN ) );
 
+    {
+        const char * ngc = vdco_get_str_option(my_args, OPTION_NGC);
+        if (ngc != NULL)
+            KConfigSetNgcFile(ngc);
+    }
+
     if ( ctx->format == df_sra_dump )
         ctx->without_sra_types = true;
 }
